@@ -703,7 +703,8 @@ class Consul(object):
                     interval=None,
                     ttl=None,
                     http=None,
-                    timeout=None):
+                    timeout=None,
+                    enable_tag_override=False):
                 """
                 Add a new service to the local agent. There is more
                 documentation on services
@@ -728,8 +729,21 @@ class Consul(object):
 
                 *script*, *interval*, *ttl*, *http*, and *timeout* arguments
                 are deprecated. use *check* instead.
+
+                *enable_tag_override* is an optional bool that enable you
+                to modify a service tags from servers(consul agent role server)
+                Default is set to False.
+                This option is only for >=v0.6.0 version on both agent and
+                servers.
+                for more information
+                https://www.consul.io/docs/agent/services.html
                 """
-                payload = {'name': name}
+
+                payload = {}
+
+                payload['name'] = name
+                if enable_tag_override:
+                    payload['enabletagoverride'] = enable_tag_override
                 if service_id:
                     payload['id'] = service_id
                 if address:
@@ -932,7 +946,13 @@ class Consul(object):
         def __init__(self, agent):
             self.agent = agent
 
-        def register(self, node, address, service=None, check=None, dc=None):
+        def register(self,
+                     node,
+                     address,
+                     service=None,
+                     check=None,
+                     dc=None,
+                     token=None):
             """
             A low level mechanism for directly registering or updating entries
             in the catalog. It is usually recommended to use
@@ -980,6 +1000,8 @@ class Consul(object):
             *dc* is the datacenter of the node and defaults to this agents
             datacenter.
 
+            *token* is an optional `ACL token`_ to apply to this request.
+
             This manipulates the health check entry, but does not setup a
             script or TTL to actually update the status. The full documentation
             is `here <https://consul.io/docs/agent/http.html#catalog>`_.
@@ -994,10 +1016,18 @@ class Consul(object):
                 data['service'] = service
             if check:
                 data['check'] = check
+            token = token or self.agent.token
+            if token:
+                data['WriteRequest'] = {'Token': token}
             return self.agent.http.put(
                 CB.bool(), '/v1/catalog/register', data=json.dumps(data))
 
-        def deregister(self, node, service_id=None, check_id=None, dc=None):
+        def deregister(self,
+                       node,
+                       service_id=None,
+                       check_id=None,
+                       dc=None,
+                       token=None):
             """
             A low level mechanism for directly removing entries in the catalog.
             It is usually recommended to use the agent APIs, as they are
@@ -1009,6 +1039,8 @@ class Consul(object):
             and *check_id* should be provided and only that service or check
             will be removed.
 
+            *token* is an optional `ACL token`_ to apply to this request.
+
             Returns *True* on success.
             """
             assert not (service_id and check_id)
@@ -1020,6 +1052,9 @@ class Consul(object):
                 data['serviceid'] = service_id
             if check_id:
                 data['checkid'] = check_id
+            token = token or self.agent.token
+            if token:
+                data['WriteRequest'] = {'Token': token}
             return self.agent.http.put(
                 CB.bool(), '/v1/catalog/deregister', data=json.dumps(data))
 
@@ -1036,7 +1071,8 @@ class Consul(object):
                 wait=None,
                 consistency=None,
                 dc=None,
-                near=None):
+                near=None,
+                token=None):
             """
             Returns a tuple of (*index*, *nodes*) of all nodes known
             about in the *dc* datacenter. *dc* defaults to the current
@@ -1056,6 +1092,8 @@ class Consul(object):
             not specified *consistency* will the consistency level this client
             was configured with.
 
+            *token* is an optional `ACL token`_ to apply to this request.
+
             The response looks like this::
 
                 (index, [
@@ -1079,13 +1117,21 @@ class Consul(object):
                     params['wait'] = wait
             if near:
                 params['near'] = near
+            token = token or self.agent.token
+            if token:
+                params['token'] = token
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
             return self.agent.http.get(
                 CB.json(index=True), '/v1/catalog/nodes', params=params)
 
-        def services(self, index=None, wait=None, consistency=None, dc=None):
+        def services(self,
+                     index=None,
+                     wait=None,
+                     consistency=None,
+                     dc=None,
+                     token=None):
             """
             Returns a tuple of (*index*, *services*) of all services known
             about in the *dc* datacenter. *dc* defaults to the current
@@ -1102,6 +1148,8 @@ class Consul(object):
             not specified *consistency* will the consistency level this client
             was configured with.
 
+            *token* is an optional `ACL token`_ to apply to this request.
+
             The response looks like this::
 
                 (index, {
@@ -1124,13 +1172,22 @@ class Consul(object):
                 params['index'] = index
                 if wait:
                     params['wait'] = wait
+            token = token or self.agent.token
+            if token:
+                params['token'] = token
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
             return self.agent.http.get(
                 CB.json(index=True), '/v1/catalog/services', params=params)
 
-        def node(self, node, index=None, wait=None, consistency=None, dc=None):
+        def node(self,
+                 node,
+                 index=None,
+                 wait=None,
+                 consistency=None,
+                 dc=None,
+                 token=None):
             """
             Returns a tuple of (*index*, *services*) of all services provided
             by *node*.
@@ -1149,6 +1206,8 @@ class Consul(object):
             *dc* is the datacenter of the node and defaults to this agents
             datacenter.
 
+            *token* is an optional `ACL token`_ to apply to this request.
+
             The response looks like this::
 
                 (index, {
@@ -1182,6 +1241,9 @@ class Consul(object):
                 params['index'] = index
                 if wait:
                     params['wait'] = wait
+            token = token or self.agent.token
+            if token:
+                params['token'] = token
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
@@ -1198,7 +1260,8 @@ class Consul(object):
                 tag=None,
                 consistency=None,
                 dc=None,
-                near=None):
+                near=None,
+                token=None):
             """
             Returns a tuple of (*index*, *nodes*) of the nodes providing
             *service* in the *dc* datacenter. *dc* defaults to the current
@@ -1221,6 +1284,8 @@ class Consul(object):
             not specified *consistency* will the consistency level this client
             was configured with.
 
+            *token* is an optional `ACL token`_ to apply to this request.
+
             The response looks like this::
 
                 (index, [
@@ -1246,6 +1311,9 @@ class Consul(object):
                     params['wait'] = wait
             if near:
                 params['near'] = near
+            token = token or self.agent.token
+            if token:
+                params['token'] = token
             consistency = consistency or self.agent.consistency
             if consistency in ('consistent', 'stale'):
                 params[consistency] = '1'
@@ -1490,7 +1558,7 @@ class Consul(object):
 
             when *ttl* is provided, the session is invalidated if it is not
             renewed before the TTL expires.  If specified, it is an integer of
-            seconds.  Currently it must be between 10 and 3600 seconds.
+            seconds.  Currently it must be between 10 and 86400 seconds.
 
             By default the session will be created in the current datacenter
             but an optional *dc* can be provided.
@@ -1515,7 +1583,7 @@ class Consul(object):
             if behavior != 'release':
                 data['behavior'] = behavior
             if ttl:
-                assert 10 <= ttl <= 3600
+                assert 10 <= ttl <= 86400
                 data['ttl'] = '%ss' % ttl
             if data:
                 data = json.dumps(data)
@@ -1758,7 +1826,7 @@ class Consul(object):
                 payload['Type'] = type
             if rules:
                 assert isinstance(rules, str), \
-                    'Only HCL encoded strings supported for the moment'
+                    'Only HCL or JSON encoded strings supported for the moment'
                 payload['Rules'] = rules
             if acl_id:
                 payload['ID'] = acl_id
@@ -1807,7 +1875,7 @@ class Consul(object):
                 payload['Type'] = type
             if rules:
                 assert isinstance(rules, str), \
-                    'Only HCL encoded strings supported for the moment'
+                    'Only HCL or JSON encoded strings supported for the moment'
                 payload['Rules'] = rules
 
             data = json.dumps(payload)
@@ -1910,37 +1978,37 @@ class Consul(object):
                         tags=None,
                         ttl=None,
                         regexp=None):
-            service_body = {
-                k: v for k, v in {
+            service_body = dict([
+                (k, v) for k, v in {
                     'service': service,
                     'onlypassing': onlypassing,
                     'tags': tags,
-                    'failover': {
-                        k: v for k, v in {
+                    'failover': dict([
+                        (k, v) for k, v in {
                             'nearestn': nearestn,
                             'datacenters': datacenters
                         }.items() if v is not None
-                    }
+                    ])
                 }.items() if v is not None
-            }
+            ])
 
-            data = {
-                k: v for k, v in {
+            data = dict([
+                (k, v) for k, v in {
                     'name': name,
                     'session': session,
                     'token': token or self.agent.token,
                     'dns': {
                         'ttl': ttl
                     } if ttl is not None else None,
-                    'template': {
-                        k: v for k, v in {
+                    'template': dict([
+                        (k, v) for k, v in {
                             'type': 'name_prefix_match',
                             'regexp': regexp
                         }.items() if v is not None
-                    },
+                    ]),
                     'service': service_body
                 }.items() if v is not None
-            }
+            ])
             return json.dumps(data)
 
         def create(self, service,
